from django.contrib.auth.decorators import login_required
from django.contrib.auth.decorators import permission_required
from django.utils.translation import gettext_lazy as _
from zen_queries import render

from .permissions import ADMINISTRATE_MEMBERS
from .selectors import get_memberships
from .selectors import get_users
from utils.view_utils import base_view_context
from utils.view_utils import render_list


@login_required
def membership_overview(request):
    memberships = get_memberships(user=request.user)
    current_membership = memberships.current()
    previous_memberships = memberships.previous()

    current_period = current_membership.period.period if current_membership else None

    context = base_view_context(request) | {
        "current_membership": current_membership,
        "current_period": current_period,
        "previous_memberships": previous_memberships,
    }

    return render(
        request=request,
        template_name="membership/membership_overview.html",
        context=context,
    )


@login_required
@permission_required(ADMINISTRATE_MEMBERS.path)
def members_admin(request):
    users = get_users()

    return render_list(
        request=request,
        objects=users,
        columns=[
            ("username", _("Username")),
            ("first_name", _("First name")),
            ("last_name", _("Last name")),
            ("email", _("Email")),
        ],
    )
